<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Validator;
use App\Models\Wendor;
use App\Models\WendorProduct;

class WendorController extends Controller
{
    public function viewWendors()
    {
        $wendor = wendor::orderBy("id","ASC")->paginate(10);
        return view('osadmin.view_wendors',compact('wendor'));
    }

    public function wendordetails($id)
    {
        $wen = wendor::with('products')->find($id);
        return view('osadmin.wendor_details',compact('wen'));
    }

    public function addWendor()
    {
        return view('osadmin.add_wendor');
    }

    public function savewendor(Request $request)
    {
       $validated = validator::make($request->all(),
        [
            'cname' => 'required|min:3',
            'wname' => 'required|min:3', 
            'email' => 'required|email',
            'mobile' => 'required|numeric',
            'gst' => 'required|min:5',
            'licence' => 'required|min:5',
            'address1' => 'required',
            'address2' => 'required',
            'pcode' => 'required',
            'country' => 'required',
            'product.*' => 'required|string',
            'size.*' => 'required|string',
            'quality.*' => 'required|string',
            'avatar.*' => 'nullable|image|max:2048',
        ]);

    if($validated->passes()){
        $wen = new wendor();
        $wen->cname = $request->cname;
        $wen->wname = $request->wname; 
        $wen->email = $request->email;
        $wen->mobile = $request->mobile;
        $wen->gst = $request->gst;
        $wen->licence = $request->licence;
        $wen->address1 = $request->address1;
        $wen->address2 = $request->address2;
        $wen->pcode = $request->pcode;
        $wen->country = $request->country;
        
        $wen->save();

        // Save the products to the wendor_products table
        if($request->has('product')) {
            foreach ($request->product as $index => $product) {
                $productData = new wendorproduct();
                $productData->v_id = $wen->v_id;
                $productData->product = $product;
                $productData->size = $request->size[$index];
                $productData->quality = $request->quality[$index];
                
                if ($request->hasFile('avatar.'.$index)) {
                    $imageName = time() . '_' . $request->file('avatar.'.$index)->getClientOriginalName();
                    $request->file('avatar.'.$index)->move(public_path('images'), $imageName);
                    $productData->image = $imageName;
                }

                $productData->save();
            }
        }

        return redirect()->route('view.wendors')->with('success', 'Wendor added successfully.');
    }
    else {
        return redirect()->route('add.wendor')->withErrors($validated)->withInput();
    }
}

    public function editwendor($id)
    {
        $ewen = wendor::with('products')->find($id);
        return view('osadmin.edit_wendor',compact('ewen'));
    }
    public function updatewendor($id, Request $request)
    {
        $validated = validator::make($request->all(),
        [
            'cname' => 'required|min:3',
            'wname' => 'required|min:3', 
            'email' => 'required|email',
            'mobile' => 'required|numeric',
            'gst' => 'required|min:5',
            'licence' => 'required|min:5',
            'address1' => 'required',
            'address2' => 'required',
            'pcode' => 'required',
            'country' => 'required',
            'product.*' => 'required|string',
            'size.*' => 'required|string',
            'quality.*' => 'required|string',
            'avatar.*' => 'nullable|image|max:2048',
        ]);

    if($validated->passes()){
        $ewen = wendor::find($id);
        $ewen->cname = $request->cname;
        $ewen->wname = $request->wname; 
        $ewen->email = $request->email;
        $ewen->mobile = $request->mobile;
        $ewen->gst = $request->gst;
        $ewen->licence = $request->licence;
        $ewen->address1 = $request->address1;
        $ewen->address2 = $request->address2;
        $ewen->pcode = $request->pcode;
        $ewen->country = $request->country;
        
        $ewen->save();

        // Save the products to the wendor_products table
        if($request->has('product')) {
            foreach ($request->product as $index => $product) {
                $eproduct = wendorproduct::find($id);
                $eproduct->v_id = $wen->v_id;
                $eproduct->product = $product;
                $eproduct->size = $request->size[$index];
                $eproduct->quality = $request->quality[$index];
                
                if ($request->hasFile('avatar.'.$index)) {
                    $imageName = time() . '_' . $request->file('avatar.'.$index)->getClientOriginalName();
                    $request->file('avatar.'.$index)->move(public_path('images'), $imageName);
                    $eproduct->image = $imageName;
                }

                $eproduct->save();
            }
        }

        return redirect()->route('view.wendors')->with('success', 'Wendor Updated successfully.');
    }
    else {
        return redirect()->route('edit.wendor',$ewen->id)->withErrors($validated)->withInput();
    }
    }
}
