<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Validator;
use App\Models\Order;
use App\Models\Order_Product;
use App\Models\quotation;


class OrderController extends Controller
{
    public function order()
    {
        return view("order");
    }

    public function save(Request $request)
    {
        // Validation rules and custom messages
        $rules = [
            "empid" => "required|min:3",
            "empname" => "required|min:3",
            "email" => "required|email",
            "mobile" => "required|numeric|min:10",
            "product.*" => "required|min:3",
            "size.*" => "required",
            "qty.*" => "required",
            "address1" => "required",
            "address2" => "required",
            "country" => "required",
            "pcode" => "required",
            "avatar.*" => "image|mimes:png,jpg,jpeg,gif,webp"
        ];

        $messages = [
            'empid.required' => 'Company Name is required.',
            'empname.required' => 'Full Name is required.',
            'email.email' => 'Please enter a valid email address.',
            'mobile.numeric' => 'Mobile number must be numeric.',
            'product.*.required' => 'Product field is required for each item.',
            'avatar.*.image' => 'Only image files are allowed for avatars.',
            'address1.required' => "Select Prority",
            'address2.required' => "Price field is required",
            'qty.*.required' => "required",
            'country.required' => "No.of Days Field is required"

        ];

        $validated = Validator::make($request->all(), $rules, $messages);

        if ($validated->passes()) {
            DB::beginTransaction();

            try {
                // Create and save the order
                $ord = new Order();
                $ord->empid = $request->empid;
                $ord->empname = $request->empname;
                $ord->email = $request->email;
                $ord->mobile = $request->mobile;
                $ord->address1 = $request->address1;
                $ord->address2 = $request->address2;
                $ord->country = $request->country;
                $ord->pcode = $request->pcode;
                $ord->save();

                foreach ($request->product as $index => $product) {
                    $orderProduct = new Order_Product();
                    $orderProduct->order_id = $ord->id; 
                    $orderProduct->product = $product;
                    $orderProduct->size = $request->size[$index];
                    $orderProduct->qty = $request->qty[$index];
                    $orderProduct->message = $request->message[$index];

                    if ($request->hasFile("avatar.$index")) {
                        $avatar = $request->file("avatar.$index");
                        $ext = $avatar->getClientOriginalExtension();
                        $str = substr(md5(str_shuffle("qwertyuioplkjhgfdsazxcvvb")), 5, 15);
                        $newfilename = $str . "_" . time() . "." . $ext;
                        $avatar->move(public_path("/assets/orders"), $newfilename);
                        $orderProduct->avatar = $newfilename;
                    }

                    $orderProduct->save(); // Save each product associated with the order
                }

                DB::commit();
                return redirect()->route('order')->with('success', "Order Placed Successfully.");
            } catch (\Exception $e) {
                DB::rollBack();
                return redirect()->route('order')->withErrors('error','An error occurred while saving your order. Please try again.')->withInput();
            }
        } else {
            return redirect()->route('order')->withErrors($validated)->withInput();
        }
    }

    public function savequotation(Request $request)
    {
        $validated = $request->validate([
            'order_id' => 'required|exists:orders,order_id',
            'product' => 'required|exists:order_products,product', 
            'ref' => 'required|min:3',
            'wname' => 'required',
            'price' => 'required|numeric',
        ]);

    
        $quo = new quotation();
        $quo->order_id = $request->order_id;
        $quo->product = $request->product; 
        $quo->ref = $request->ref;
        $quo->wname = $request->wname;
        $quo->price = $request->price;
        $quo->save();

        return redirect()->route('view.orders')->with('success', 'Quotation added successfully.');
    }
    
}
